Skip to content

CLI Reference

This reference is generated from the clap comments and attributes in crates/tryke/src/cli.rs.

tryke

Usage: tryke [OPTIONS] <COMMAND>

Commands:
  test    Collect and run tests
  watch   Watch files and rerun affected tests
  server  Start a persistent worker server
  graph   Print the import dependency graph for the project
  help    Print this message or the help of the given subcommand(s)

Options:
  -v, --verbose...
          Increase logging verbosity

  -q, --quiet...
          Decrease logging verbosity

  -h, --help
          Print help

  -V, --version
          Print version

tryke graph

Print the import dependency graph for the project

Print the import dependency graph for the project

Usage: tryke graph [OPTIONS]

Options:
      --root <ROOT>
          Project root used for discovery and execution

  -e, --exclude <EXCLUDE>
          Exclude files/directories from discovery (overrides pyproject config)

  -i, --include <INCLUDE>
          Include files/directories even if excluded by `pyproject.toml`

      --connected-only
          Show only files that have dependents or dependencies (skip isolated files)

      --changed
          Show only files affected by files changed since HEAD (requires git)

  -v, --verbose...
          Increase logging verbosity

      --base-branch <BASE_BRANCH>
          Base branch for --changed (e.g. "main"). Uses merge-base diff

  -q, --quiet...
          Decrease logging verbosity

  -h, --help
          Print help

tryke server

Start a persistent worker server

Start a persistent worker server

Usage: tryke server [OPTIONS]

Options:
      --port <PORT>
          Port for the server

          [default: 2337]

      --root <ROOT>
          Project root used for discovery and execution

  -e, --exclude <EXCLUDE>
          Exclude files/directories from discovery (overrides pyproject config)

  -i, --include <INCLUDE>
          Include files/directories even if excluded by `pyproject.toml`

  -v, --verbose...
          Increase logging verbosity

  -q, --quiet...
          Decrease logging verbosity

  -h, --help
          Print help

tryke test

Collect and run tests

Collect and run tests

Usage: tryke test [OPTIONS] [PATHS]...

Arguments:
  [PATHS]...
          File paths or file:line specs to restrict collection

Options:
  -e, --exclude <EXCLUDE>
          Exclude files/directories from discovery (overrides pyproject config)

  -i, --include <INCLUDE>
          Include files/directories even if excluded by `pyproject.toml`

      --collect-only
          Collect tests without running them

  -k, --filter <FILTER>
          Filter expression (e.g. "math and not slow")

  -m, --markers <MARKERS>
          Tag/marker filter expression (e.g. "slow and not network")

  -v, --verbose...
          Increase logging verbosity

  -q, --quiet...
          Decrease logging verbosity

      --reporter <REPORTER>
          Reporter format to use for output

          [default: text]
          [possible values: text, json, dot, junit, llm]

      --root <ROOT>
          Project root used for discovery and execution

      --port [<PORT>]
          Use an already-running server on the optional port

      --changed
          Run only tests affected by files changed since HEAD (requires git)

      --changed-first
          Run changed tests first, then all remaining tests (requires git)

      --base-branch <BASE_BRANCH>
          Base branch for --changed or --changed-first (e.g. "main"). Uses merge-base diff

  -x, --fail-fast
          Stop after first failure

      --maxfail <MAXFAIL>
          Stop after N failures

  -j, --workers <WORKERS>
          Number of worker processes (default: min(test_count, cpu_count))

  -h, --help
          Print help

tryke watch

Watch files and rerun affected tests

Watch files and rerun affected tests

Usage: tryke watch [OPTIONS]

Options:
  -e, --exclude <EXCLUDE>
          Exclude files/directories from discovery (overrides pyproject config)

  -i, --include <INCLUDE>
          Include files/directories even if excluded by `pyproject.toml`

  -k, --filter <FILTER>
          Filter expression (e.g. "math and not slow")

  -m, --markers <MARKERS>
          Tag/marker filter expression (e.g. "slow and not network")

      --reporter <REPORTER>
          Reporter format to use for output

          [default: text]
          [possible values: text, json, dot, junit, llm]

  -v, --verbose...
          Increase logging verbosity

  -q, --quiet...
          Decrease logging verbosity

      --root <ROOT>
          Project root used for discovery and execution

  -x, --fail-fast
          Stop after first failure

      --maxfail <MAXFAIL>
          Stop after N failures

  -j, --workers <WORKERS>
          Number of worker processes (default: cpu_count)

  -h, --help
          Print help